import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CustomDirectoryRoleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The description of the custom directory role
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#description CustomDirectoryRole#description}
    */
    readonly description?: string;
    /**
    * The display name of the custom directory role
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#display_name CustomDirectoryRole#display_name}
    */
    readonly displayName: string;
    /**
    * Indicates whether the role is enabled for assignment
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#enabled CustomDirectoryRole#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Custom template identifier that is typically used if one needs an identifier to be the same across different directories.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#template_id CustomDirectoryRole#template_id}
    */
    readonly templateId?: string;
    /**
    * The version of the role definition.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#version CustomDirectoryRole#version}
    */
    readonly version: string;
    /**
    * permissions block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#permissions CustomDirectoryRole#permissions}
    */
    readonly permissions: CustomDirectoryRolePermissions[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#timeouts CustomDirectoryRole#timeouts}
    */
    readonly timeouts?: CustomDirectoryRoleTimeouts;
}
export interface CustomDirectoryRolePermissions {
    /**
    * Set of tasks that can be performed on a resource
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#allowed_resource_actions CustomDirectoryRole#allowed_resource_actions}
    */
    readonly allowedResourceActions: string[];
}
export declare function customDirectoryRolePermissionsToTerraform(struct?: CustomDirectoryRolePermissions | cdktf.IResolvable): any;
export interface CustomDirectoryRoleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#create CustomDirectoryRole#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#delete CustomDirectoryRole#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#read CustomDirectoryRole#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role#update CustomDirectoryRole#update}
    */
    readonly update?: string;
}
export declare function customDirectoryRoleTimeoutsToTerraform(struct?: CustomDirectoryRoleTimeoutsOutputReference | CustomDirectoryRoleTimeouts | cdktf.IResolvable): any;
export declare class CustomDirectoryRoleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): CustomDirectoryRoleTimeouts | undefined;
    set internalValue(value: CustomDirectoryRoleTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role azuread_custom_directory_role}
*/
export declare class CustomDirectoryRole extends cdktf.TerraformResource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azuread/r/custom_directory_role azuread_custom_directory_role} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CustomDirectoryRoleConfig
    */
    constructor(scope: Construct, id: string, config: CustomDirectoryRoleConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    get id(): string;
    get objectId(): string;
    private _templateId?;
    get templateId(): string;
    set templateId(value: string);
    resetTemplateId(): void;
    get templateIdInput(): string | undefined;
    private _version?;
    get version(): string;
    set version(value: string);
    get versionInput(): string | undefined;
    private _permissions?;
    get permissions(): CustomDirectoryRolePermissions[] | cdktf.IResolvable;
    set permissions(value: CustomDirectoryRolePermissions[] | cdktf.IResolvable);
    get permissionsInput(): cdktf.IResolvable | CustomDirectoryRolePermissions[] | undefined;
    private _timeouts;
    get timeouts(): CustomDirectoryRoleTimeoutsOutputReference;
    putTimeouts(value: CustomDirectoryRoleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): CustomDirectoryRoleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
