import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzureadApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The Application ID (also called Client ID)
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/application#application_id DataAzureadApplication#application_id}
    */
    readonly applicationId?: string;
    /**
    * The display name for the application
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/application#display_name DataAzureadApplication#display_name}
    */
    readonly displayName?: string;
    /**
    * The application's object ID
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/application#object_id DataAzureadApplication#object_id}
    */
    readonly objectId?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/application#timeouts DataAzureadApplication#timeouts}
    */
    readonly timeouts?: DataAzureadApplicationTimeouts;
}
export declare class DataAzureadApplicationApiOauth2PermissionScopes extends cdktf.ComplexComputedList {
    get adminConsentDescription(): string;
    get adminConsentDisplayName(): string;
    get enabled(): cdktf.IResolvable;
    get id(): string;
    get type(): string;
    get userConsentDescription(): string;
    get userConsentDisplayName(): string;
    get value(): string;
}
export declare class DataAzureadApplicationApi extends cdktf.ComplexComputedList {
    get knownClientApplications(): string[];
    get mappedClaimsEnabled(): cdktf.IResolvable;
    get oauth2PermissionScopes(): cdktf.IResolvable;
    get requestedAccessTokenVersion(): number;
}
export declare class DataAzureadApplicationAppRoles extends cdktf.ComplexComputedList {
    get allowedMemberTypes(): string[];
    get description(): string;
    get displayName(): string;
    get enabled(): cdktf.IResolvable;
    get id(): string;
    get value(): string;
}
export declare class DataAzureadApplicationFeatureTags extends cdktf.ComplexComputedList {
    get customSingleSignOn(): cdktf.IResolvable;
    get enterprise(): cdktf.IResolvable;
    get gallery(): cdktf.IResolvable;
    get hide(): cdktf.IResolvable;
}
export declare class DataAzureadApplicationOptionalClaimsAccessToken extends cdktf.ComplexComputedList {
    get additionalProperties(): string[];
    get essential(): cdktf.IResolvable;
    get name(): string;
    get source(): string;
}
export declare class DataAzureadApplicationOptionalClaimsIdToken extends cdktf.ComplexComputedList {
    get additionalProperties(): string[];
    get essential(): cdktf.IResolvable;
    get name(): string;
    get source(): string;
}
export declare class DataAzureadApplicationOptionalClaimsSaml2Token extends cdktf.ComplexComputedList {
    get additionalProperties(): string[];
    get essential(): cdktf.IResolvable;
    get name(): string;
    get source(): string;
}
export declare class DataAzureadApplicationOptionalClaims extends cdktf.ComplexComputedList {
    get accessToken(): cdktf.IResolvable;
    get idToken(): cdktf.IResolvable;
    get saml2Token(): cdktf.IResolvable;
}
export declare class DataAzureadApplicationPublicClient extends cdktf.ComplexComputedList {
    get redirectUris(): string[];
}
export declare class DataAzureadApplicationRequiredResourceAccessResourceAccess extends cdktf.ComplexComputedList {
    get id(): string;
    get type(): string;
}
export declare class DataAzureadApplicationRequiredResourceAccess extends cdktf.ComplexComputedList {
    get resourceAccess(): cdktf.IResolvable;
    get resourceAppId(): string;
}
export declare class DataAzureadApplicationSinglePageApplication extends cdktf.ComplexComputedList {
    get redirectUris(): string[];
}
export declare class DataAzureadApplicationWebImplicitGrant extends cdktf.ComplexComputedList {
    get accessTokenIssuanceEnabled(): cdktf.IResolvable;
    get idTokenIssuanceEnabled(): cdktf.IResolvable;
}
export declare class DataAzureadApplicationWeb extends cdktf.ComplexComputedList {
    get homepageUrl(): string;
    get implicitGrant(): cdktf.IResolvable;
    get logoutUrl(): string;
    get redirectUris(): string[];
}
export interface DataAzureadApplicationTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/application#read DataAzureadApplication#read}
    */
    readonly read?: string;
}
export declare function dataAzureadApplicationTimeoutsToTerraform(struct?: DataAzureadApplicationTimeoutsOutputReference | DataAzureadApplicationTimeouts | cdktf.IResolvable): any;
export declare class DataAzureadApplicationTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataAzureadApplicationTimeouts | undefined;
    set internalValue(value: DataAzureadApplicationTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azuread/d/application azuread_application}
*/
export declare class DataAzureadApplication extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azuread/d/application azuread_application} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzureadApplicationConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataAzureadApplicationConfig);
    api(index: string): DataAzureadApplicationApi;
    appRoleIds(key: string): string | cdktf.IResolvable;
    appRoles(index: string): DataAzureadApplicationAppRoles;
    private _applicationId?;
    get applicationId(): string;
    set applicationId(value: string);
    resetApplicationId(): void;
    get applicationIdInput(): string | undefined;
    get deviceOnlyAuthEnabled(): cdktf.IResolvable;
    get disabledByMicrosoft(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    get fallbackPublicClientEnabled(): cdktf.IResolvable;
    featureTags(index: string): DataAzureadApplicationFeatureTags;
    get groupMembershipClaims(): string[];
    get id(): string;
    get identifierUris(): string[];
    get logoUrl(): string;
    get marketingUrl(): string;
    oauth2PermissionScopeIds(key: string): string | cdktf.IResolvable;
    get oauth2PostResponseRequired(): cdktf.IResolvable;
    private _objectId?;
    get objectId(): string;
    set objectId(value: string);
    resetObjectId(): void;
    get objectIdInput(): string | undefined;
    optionalClaims(index: string): DataAzureadApplicationOptionalClaims;
    get owners(): string[];
    get privacyStatementUrl(): string;
    publicClient(index: string): DataAzureadApplicationPublicClient;
    get publisherDomain(): string;
    requiredResourceAccess(index: string): DataAzureadApplicationRequiredResourceAccess;
    get signInAudience(): string;
    singlePageApplication(index: string): DataAzureadApplicationSinglePageApplication;
    get supportUrl(): string;
    get tags(): string[];
    get termsOfServiceUrl(): string;
    web(index: string): DataAzureadApplicationWeb;
    private _timeouts;
    get timeouts(): DataAzureadApplicationTimeoutsOutputReference;
    putTimeouts(value: DataAzureadApplicationTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzureadApplicationTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
