import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzureadServicePrincipalConfig extends cdktf.TerraformMetaArguments {
    /**
    * The application ID (client ID) of the application associated with this service principal
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principal#application_id DataAzureadServicePrincipal#application_id}
    */
    readonly applicationId?: string;
    /**
    * The display name of the application associated with this service principal
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principal#display_name DataAzureadServicePrincipal#display_name}
    */
    readonly displayName?: string;
    /**
    * The object ID of the service principal
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principal#object_id DataAzureadServicePrincipal#object_id}
    */
    readonly objectId?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principal#timeouts DataAzureadServicePrincipal#timeouts}
    */
    readonly timeouts?: DataAzureadServicePrincipalTimeouts;
}
export declare class DataAzureadServicePrincipalAppRoles extends cdktf.ComplexComputedList {
    get allowedMemberTypes(): string[];
    get description(): string;
    get displayName(): string;
    get enabled(): cdktf.IResolvable;
    get id(): string;
    get value(): string;
}
export declare class DataAzureadServicePrincipalFeatureTags extends cdktf.ComplexComputedList {
    get customSingleSignOn(): cdktf.IResolvable;
    get enterprise(): cdktf.IResolvable;
    get gallery(): cdktf.IResolvable;
    get hide(): cdktf.IResolvable;
}
export declare class DataAzureadServicePrincipalFeatures extends cdktf.ComplexComputedList {
    get customSingleSignOnApp(): cdktf.IResolvable;
    get enterpriseApplication(): cdktf.IResolvable;
    get galleryApplication(): cdktf.IResolvable;
    get visibleToUsers(): cdktf.IResolvable;
}
export declare class DataAzureadServicePrincipalOauth2PermissionScopes extends cdktf.ComplexComputedList {
    get adminConsentDescription(): string;
    get adminConsentDisplayName(): string;
    get enabled(): cdktf.IResolvable;
    get id(): string;
    get type(): string;
    get userConsentDescription(): string;
    get userConsentDisplayName(): string;
    get value(): string;
}
export declare class DataAzureadServicePrincipalSamlSingleSignOn extends cdktf.ComplexComputedList {
    get relayState(): string;
}
export interface DataAzureadServicePrincipalTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azuread/d/service_principal#read DataAzureadServicePrincipal#read}
    */
    readonly read?: string;
}
export declare function dataAzureadServicePrincipalTimeoutsToTerraform(struct?: DataAzureadServicePrincipalTimeoutsOutputReference | DataAzureadServicePrincipalTimeouts | cdktf.IResolvable): any;
export declare class DataAzureadServicePrincipalTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): DataAzureadServicePrincipalTimeouts | undefined;
    set internalValue(value: DataAzureadServicePrincipalTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azuread/d/service_principal azuread_service_principal}
*/
export declare class DataAzureadServicePrincipal extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azuread/d/service_principal azuread_service_principal} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzureadServicePrincipalConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataAzureadServicePrincipalConfig);
    get accountEnabled(): cdktf.IResolvable;
    get alternativeNames(): string[];
    get appRoleAssignmentRequired(): cdktf.IResolvable;
    appRoleIds(key: string): string | cdktf.IResolvable;
    appRoles(index: string): DataAzureadServicePrincipalAppRoles;
    private _applicationId?;
    get applicationId(): string;
    set applicationId(value: string);
    resetApplicationId(): void;
    get applicationIdInput(): string | undefined;
    get applicationTenantId(): string;
    get description(): string;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    resetDisplayName(): void;
    get displayNameInput(): string | undefined;
    featureTags(index: string): DataAzureadServicePrincipalFeatureTags;
    features(index: string): DataAzureadServicePrincipalFeatures;
    get homepageUrl(): string;
    get id(): string;
    get loginUrl(): string;
    get logoutUrl(): string;
    get notes(): string;
    get notificationEmailAddresses(): string[];
    oauth2PermissionScopeIds(key: string): string | cdktf.IResolvable;
    oauth2PermissionScopes(index: string): DataAzureadServicePrincipalOauth2PermissionScopes;
    private _objectId?;
    get objectId(): string;
    set objectId(value: string);
    resetObjectId(): void;
    get objectIdInput(): string | undefined;
    get preferredSingleSignOnMode(): string;
    get redirectUris(): string[];
    get samlMetadataUrl(): string;
    samlSingleSignOn(index: string): DataAzureadServicePrincipalSamlSingleSignOn;
    get servicePrincipalNames(): string[];
    get signInAudience(): string;
    get tags(): string[];
    get type(): string;
    private _timeouts;
    get timeouts(): DataAzureadServicePrincipalTimeoutsOutputReference;
    putTimeouts(value: DataAzureadServicePrincipalTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzureadServicePrincipalTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
